==> eleme-openapi-sdk-1.30.71-sources.jar: eleme/openapi/sdk/api/entity/merchant/PersonalMerchantIdentityCO.java <==
package eleme.openapi.sdk.api.entity.merchant;

import java.util.*;
import com.fasterxml.jackson.annotation.JsonFormat;

public class PersonalMerchantIdentityCO{

    /**
     * 商户名称
     */
    private String name;
    public String getName() {
        return name;
    }
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * 个人证件类型
     */
    private String licenseType;
    public String getLicenseType() {
        return licenseType;
    }
    public void setLicenseType(String licenseType) {
        this.licenseType = licenseType;
    }
    
    /**
     * 个人证件号码
     */
    private String licenseNo;
    public String getLicenseNo() {
        return licenseNo;
    }
    public void setLicenseNo(String licenseNo) {
        this.licenseNo = licenseNo;
    }
    
    /**
     * 证件到期时间
     */
    @JsonFormat(locale = "zh" , timezone="GMT+8")
    private Date licenseEnd;
    public Date getLicenseEnd() {
        return licenseEnd;
    }
    public void setLicenseEnd(Date licenseEnd) {
        this.licenseEnd = licenseEnd;
    }
    
    /**
     * 证件正面照
     */
    private String licenseHash;
    public String getLicenseHash() {
        return licenseHash;
    }
    public void setLicenseHash(String licenseHash) {
        this.licenseHash = licenseHash;
    }
    
    /**
     * 证件背面照
     */
    private String licenseBackHash;
    public String getLicenseBackHash() {
        return licenseBackHash;
    }
    public void setLicenseBackHash(String licenseBackHash) {
        this.licenseBackHash = licenseBackHash;
    }
    
}

==> eleme-openapi-sdk-1.31.37-sources.jar: eleme/openapi/sdk/api/entity/merchant/PersonalMerchantIdentityCO.java <==
package eleme.openapi.sdk.api.entity.merchant;

import eleme.openapi.sdk.api.enumeration.merchant.*;
import eleme.openapi.sdk.api.entity.merchant.*;
import java.util.*;
import java.math.BigDecimal;
import com.fasterxml.jackson.annotation.JsonFormat;

public class PersonalMerchantIdentityCO{

    /**
     * 商户名称
     */
    private String name;
    public String getName() {
        return name;
    }
    public void setName(String name) {
        this.name = name;
    }
    
    /**
     * 个人证件类型
     */
    private String licenseType;
    public String getLicenseType() {
        return licenseType;
    }
    public void setLicenseType(String licenseType) {
        this.licenseType = licenseType;
    }
    
    /**
     * 个人证件号码
     */
    private String licenseNo;
    public String getLicenseNo() {
        return licenseNo;
    }
    public void setLicenseNo(String licenseNo) {
        this.licenseNo = licenseNo;
    }
    
    /**
     * 证件到期时间
     */
    @JsonFormat(locale = "zh" , timezone="GMT+8")
    private Date licenseEnd;
    public Date getLicenseEnd() {
        return licenseEnd;
    }
    public void setLicenseEnd(Date licenseEnd) {
        this.licenseEnd = licenseEnd;
    }
    
    /**
     * 证件正面照
     */
    private String licenseHash;
    public String getLicenseHash() {
        return licenseHash;
    }
    public void setLicenseHash(String licenseHash) {
        this.licenseHash = licenseHash;
    }
    
    /**
     * 证件背面照
     */
    private String licenseBackHash;
    public String getLicenseBackHash() {
        return licenseBackHash;
    }
    public void setLicenseBackHash(String licenseBackHash) {
        this.licenseBackHash = licenseBackHash;
    }
    
}
